@@ -6,7 +6,7 @@ from abc import ABC
 
 from sqlalchemy import TypeDecorator, Text, Integer
 
-from ms_utils import convert_date_to_timestamp, convert_timestamp_to_date
+from .func_date import convert_date_to_timestamp, convert_timestamp_to_date
 
 
 class JsonEncodeDict(TypeDecorator, ABC):
